@@ -1,4 +1,4 @@
-from typing import Any, Callable, TYPE_CHECKING, Type, Union
+from typing import TYPE_CHECKING, Any, Callable, Type, Union
 
 if TYPE_CHECKING:
     from graia.broadcast.interfaces.dispatcher import DispatcherInterface
@@ -9,4 +9,13 @@ T_Dispatcher = Union[
 
 T_Dispatcher_Callable = Callable[["DispatcherInterface"], Any]
 
+DEFAULT_LIFECYCLE_NAMES = (
+    "beforeDispatch",
+    "afterDispatch",
+    "beforeExecution",
+    "afterExecution",
+    "beforeTargetExec",
+    "afterTargetExec",
+)
+
 from graia.broadcast.entities.dispatcher import BaseDispatcher
